// Voice pack conversion driver interface
//
// This is the main GUI and interface for executing "Voice Pack Conversion Driver" scripts.
// ECM 5.0 Includes 2 VP Conversion Drivers:
// - VoicePack Legacy Protocol
// - VoicePackDX Protocol
//
// The result of a conversion is 1 or more Voice Pack Definition files in the new VPECM protocol
//

///D//O//C//U//M//E//N//T//A//T//I//O//N///////////////////////////////////////////////////////////////////////
// VoicePackECM Protocol - A voicepack implementation protocol based on VoicePackDX
//
// - Overview
// ECM 5.0 and Voicepacks
// This new version of ECM has integrated voicepack support. It will allow a user to define an "entrty-point"
// to a voicepack's heirarchical menu tree through the menu editor. ECM also allows for a voicepack developer
// to define "default" locations for these entry point binds. One of the big differences in this implementation
// compared to others, is that each voicepack's structure is given its own memory/object. They are not binded
// directly to the chat menu's structure. They are instead, "pointed at" by entry point items in the main menu.
// This allows a user to define multiple entry points for the same voicepack. Also, ECM scans the
// scripts/voicepacks directory for definition files. If the meet certain criteria, they will be "registered"
// automatically. This eliminates the need for a "registration" script in the script/autoexec directory.



//The ECM Voicepack Conversion Object
if (isObject(ECMVPConversion))
	ECMVPConversion.delete();
	
new ScriptObject(ECMVPConversion) {
	class = "ECMVPConversion";
	OldVoicePackCount = 0;
	ProDriverCount = 0;
};


//The ECM Voicepack Conversion Class

//DRIVER INSTALLATION FUNCTIONS
//This function adds a protocol to the list of available conversion drivers, and returns a %protoID for future reference
function ECMVPConversion::RegisterProtocol(%this, %obj) {

	%this.ProDriver[%this.ProDriverCount] = %obj;
	%this.ProDriverCount++;
	
	return (%this.ProDriverCount - 1);


}

//This function will search out and execute driver files in the base/scripts/TDX/ECM/VPDrivers folder
function ECMVPConversion::LoadDrivers(%this) {

	//Get a list of all script files in the VPDriver directory
	for(%file = findFirstFile("scripts/TDX/ECM/VPDrivers/*.drv.cs"); %file !$= ""; %file = findNextFile("scripts/TDX/ECM/VPDrivers/*.drv.cs"))
		exec(%file);

}



///DRIVER IMPLEMENTATION FUNCTIONS

//This function registers a VoicePack to be converted under a certain protocol. Protocol drivers are to call this function
//in response to legacy "registration" functions
function ECMVPConversion::RegisterOldPack(%this, %ID, %file, %protoID) {

	echo("\c6 Old Voicepack Detected - " @ %file @ " - ID: " @ %ID @ " - Type: " @ %this.ProDriver[%protoID].Name);

	%this.OldVoicePack[%this.OldVoicePackCount] = new ScriptObject() {
		
		ID = %ID;
		FileName = %file;
		ProtocolID = %protoID;
		
	};
	
	%this.OldVoicePackCount++;
	
}



//GUI Functions...
function ECMVoicePacksConverter::onWake( %this ) {

	ECMOldPackList.fillList();

}

//Voice Pack listing needs to be (re)filled
function ECMOldPackList::fillList( %this ) {

	%this.clear();
	for ( %i = 0; %i < ECMVPConversion.OldVoicePackCount; %i++ ) {

		%this.addRow( %i, (ECMVPConversion.OldVoicePack[%i].ID @ " Voice Pack [" @ ECMVPConversion.ProDriver[ECMVPConversion.OldVoicePack[%i].ProtocolID].Name @ "]"));

	}

}

//Called by the "Convert" button
function ECMVPConversion::ConvertSelected(%this) {

	//Get selected item:
	%itemNum = ECMOldPackList.getSelectedId();
	
	//Display Prompt
	MessageBoxYesNo("ECM CONVERTER", "You have chosen to convert the voicepack '" @ %this.OldVoicePack[%itemNum].ID @ "'. The original files will not be changed in this process. Do you wish to proceed?", "ECMVPConversion.ConvertNow(" @ %itemNum @ ");");

}
function ECMVPConversion::ConvertNow(%this, %id) {

	//Show dialog while cnverting...
	MessagePopup( "CONVERSION UTILITY", "Converting voicepack to ECM Protocol\nThis could take a bit...");
	Canvas.repaint(); //Make Sure this message is displayed before the client lockup from processing
	
	//Call the driver's conversion function with appropriate data...
	%this.ProDriver[%this.OldVoicePack[%id].ProtocolID].ConvertVoicePack(%this.OldVoicePack[%id].ID, %this.OldVoicePack[%id].Filename);
	
	//Hide dialog
	CloseMessagePopup();
	
	//Show restart message
	MessageBoxOK( "CONVERSION UTILITY", "You will need to restart Tribes 2 to see the newly converted voicepacks in ECM. You may do so at any time.");

}



//Load Driver Files
ECMVPConversion.LoadDrivers();
